@@ -4,9 +4,10 @@
     clippy::pedantic,
     clippy::missing_inline_in_public_items
 )]
-#![allow(clippy::non_ascii_literal, clippy::inline_always)]
-#![cfg_attr(nightly, feature(str_internals, unboxed_closures, fn_traits))]
 #![forbid(unsafe_code)]
+#![allow(clippy::non_ascii_literal, clippy::inline_always, unknown_lints)]
+#![deny(clippy::semicolon_if_nothing_returned)]
+#![cfg_attr(nightly, feature(str_internals, unboxed_closures, fn_traits))]
 #![doc(test(attr(deny(warnings), forbid(unsafe_code))))]
 //! UI testing for arbitrary [`Command`]s.
 //!
@@ -516,11 +517,18 @@ pub trait CommandExt: Sealed {
         self.try_run(output, normalizer, |s| s.success());
     }
 
-    /// Equivalent to [`Self::try_run`] with `|s| !s.success()` as `check_status`.
+    /// Equivalent to [`Self::exit_with_code(output, normalizer, 1)`](Self::exit_with_code).
     #[track_caller]
     #[inline(always)]
     fn run_fail(&mut self, output: Output!(), normalizer: impl Normalizer) {
-        self.try_run(output, normalizer, |s| !s.success());
+        self.exit_with_code(output, normalizer, 1);
+    }
+
+    /// Equivalent to [`Self::try_run`] with `|s| s.code() == Some(code)` as `check_status`.
+    #[track_caller]
+    #[inline(always)]
+    fn exit_with_code(&mut self, output: Output!(), normalizer: impl Normalizer, code: i32) {
+        self.try_run(output, normalizer, |s| s.code() == Some(code));
     }
 }
 
